#
# spec file for package libtracecmd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libtracecmd
%define lname   libtracecmd1
Version:        1.4.0
Release:        1.1
Summary:        Library for creating and reading trace-cmd data files
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://git.kernel.org/pub/scm/utils/trace-cmd/trace-cmd.git
Source:         https://git.kernel.org/pub/scm/utils/trace-cmd/trace-cmd.git/snapshot/trace-cmd-libtracecmd-%version.tar.gz
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  libtraceevent-devel
BuildRequires:  libtracefs-devel >= 1.6
BuildRequires:  libzstd-devel
BuildRequires:  meson
BuildRequires:  source-highlight
BuildRequires:  xmlto

%description
Library for creating and reading trace-cmd data files

%package -n %lname
Summary:        Library for creating and reading trace-cmd data files
Group:          System/Libraries

%description -n %lname
Library for creating and reading trace-cmd data files

%package devel
Summary:        Development files for libtracecmd
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Development files of the libtracecmd library

%prep
%autosetup -p1 -n trace-cmd-libtracecmd-%version

%build
cd lib
%meson \
    --default-library=shared \
    -Dhtmldir="%_docdir/%name"
%meson_build
%meson_build docs

%install
cd lib
%meson_install

%fdupes %buildroot/%_prefix

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libtracecmd.so.1*
%license COPYING.LIB

%files devel
%_includedir/trace-cmd
%_libdir/libtracecmd.so
%_libdir/pkgconfig/*.pc
%_mandir/man*/*
%_docdir/libtracecmd
%license COPYING.LIB
%doc README

%changelog
* Thu Nov  9 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.4.0
  * trace-cmd extract: Do not extract top level unless told to
- Drop 0001-libtracecmd-Add-initial-support-for-meson.patch
  0002-trace-cmd-Add-initial-support-for-meson.patch (merged)
* Tue Feb  7 2023 Daniel Wagner <daniel.wagner@suse.com>
- Sync meson build patch with latest upstream version
  * Documentation is built via extra build target
* Sun Jan 22 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.1
  * No changelog was provided
- Delete static-assign.patch
* Wed Dec 28 2022 Daniel Wagner <daniel.wagner@suse.com>
- Build project with Meson
  * add 0001-libtracecmd-Add-initial-support-for-meson.patch
  * add 0002-trace-cmd-Add-initial-support-for-meson.patch
* Fri Dec 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0
  * Only set trace-cmd log level (not libtracefs nor libtraceevent)
  * Fix function graph plugin updating the next record
  * Use libtracefs tracefs_cpu() interface for recording
    (requires libtracefs 1.6)
* Sat Dec  3 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0
  * Process trace_clock for v7 trace.dat files
  * Add network roles for time sync
  * Have clock source TAI parse to seconds
  * Use uncompressed size for file size
  * Allow callers to save private data in tracecmd_input handlers
  * Add filtering logic for iterating events
  * Add man pages for iterator functions
  * Add API for mapping between host and guests
- Delete 0001-build-Only-consider-libtracecmd-documentation.patch,
  0002-trace-cmd-library-Fix-decleration-of-msg_lseek.patch (merged)
- Add static-assign.patch
* Mon Sep  5 2022 Daniel Wagner <daniel.wagner@suse.com>
- Drop previous added file extension glob on man pages. Whether it's
  compressed or not is an implementation detail.
* Tue Aug 30 2022 Daniel Wagner <daniel.wagner@suse.com>
- Add file extension on glob in %%files section for man pages
- Set Group to Development/Libraries/C and C++
* Tue Aug 23 2022 Daniel Wagner <daniel.wagner@suse.com>
- Initial version libtracecmd 1.1.3
  Split libtracecmd from trace-cmd into a separate package because
  libracecmd has a different release cycle and doesn't allign with
  trace-cmd.
  - Add 0001-build-Only-consider-libtracecmd-documentation.patch
  - Add 0002-trace-cmd-library-Fix-decleration-of-msg_lseek.patch
